#!/bin/bash

# Packager : JP <jp.guillemin@free.fr>
# src : http://0pointer.de/lennart/projects/libcanberra/

soft='libcanberra'
softversion='0.28'
packageversion='72.4'

arch='i486'
cpu='i686'

buildir=$(pwd)
srcpkg="$buildir/$soft-$softversion.tar.gz"
src="$buildir/$soft-$softversion"
package="$soft-$softversion-$arch-$packageversion"
packagepulse="$soft-pulseaudio-$softversion-$arch-$packageversion"
dest="/tmp/$package"
destpulse="/tmp/$packagepulse"

cd $buildir
rm -rf $src
tar -xvf $srcpkg
rm -f $dest.txz
rm -rf $dest
mkdir -p $dest

cd $src
chown -R root:root .
find . \
 \( -perm 777 -o -perm 775 -o -perm 711 -o -perm 555 -o -perm 511 \) \
 -exec chmod 755 {} \; -o \
 \( -perm 666 -o -perm 664 -o -perm 600 -o -perm 444 -o -perm 440 -o -perm 400 \) \
 -exec chmod 644 {} \;
export CFLAGS="-O2 -march=$arch -mtune=$cpu" 
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"

patch -p1 < ../0001-Workaround-a-hang-if-there-are-server-problems.patch

./configure \
--prefix=/usr \
--sysconfdir=/etc \
--mandir=/usr/man \
--docdir=/usr/doc/$soft-$softversion \
--disable-oss \
--enable-pulse \
--enable-alsa \
--disable-lynx \
--disable-gtk-doc \
--enable-gstreamer \
--with-html-dir=/usr/doc/$soft-$softversion \
--disable-schemas-install \
--with-gconf-source="xml::/etc/gconf/gconf.xml.defaults"

make -j6
make install DESTDIR=$dest

# Fix sound system file not found
sed -i -e "s/system-ready/service-login/g" $dest/usr/share/gdm/autostart/LoginWindow/libcanberra-ready-sound.desktop


( cd $dest
  find . | xargs file | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded
)
( cd $dest/usr/man
  find . -name "*.?" | xargs gzip -9
)

# gconf stuff

export GCONF_CONFIG_SOURCE="xml::$dest/etc/gconf/gconf.xml.defaults"
install -v -d -m755 $dest/etc/gconf/schemas
install -v -d -m755 $dest/etc/gconf/gconf.xml.defaults

for schema in $dest/etc/gconf/schemas/*.schemas; do
	gconftool-2 --makefile-install-rule $schema
done
# Reset / Verify correct permissions
( cd $dest/etc/gconf ; find . -type d -exec chmod 755 {} \; )
( cd $dest/etc/gconf ; find . -type f -exec chmod 644 {} \; )

mkdir -p $dest/usr/doc/$soft-$softversion
cp -a README $dest/usr/doc/$soft-$softversion

mkdir -p $dest/etc/xdg
mv $dest/usr/share/gnome/autostart $dest/etc/xdg/autostart
rm -rf $dest/usr/share/gnome

# redundant
rm -rf $dest/usr/share/doc

mkdir -p $dest/install 
cat << "EOF" > $dest/install/slack-desc
libcanberra: libcanberra - XDG event sounds generator
libcanberra: 
libcanberra: libcanberra is an implementation of the XDG Sound Theme 
libcanberra: and Name Specifications.
libcanberra: 
libcanberra: 
libcanberra: 
libcanberra: 
libcanberra: 
libcanberra: 
libcanberra: 
EOF

#create libcanberra pulse package
mkdir -p "$destpulse/usr/lib/$soft-$softversion"
cd "$dest/usr/lib/$soft-$softversion"
mv libcanberra-pulse.* "$destpulse/usr/lib/$soft-$softversion"

mkdir -p $destpulse/install 
cat << "EOF" > $destpulse/install/slack-desc
libcanberra-pulseaudio: libcanberra-pulseaudio - XDG event sounds generator
libcanberra-pulseaudio: 
libcanberra-pulseaudio: libcanberra-pulseaudio is the extra package with  
libcanberra-pulseaudio: pulseaudio support.
libcanberra-pulseaudio: 
libcanberra-pulseaudio: 
libcanberra-pulseaudio: 
libcanberra-pulseaudio: 
libcanberra-pulseaudio: 
libcanberra-pulseaudio: 
libcanberra-pulseaudio: 
EOF

cd $destpulse
makepkg -l y -c n $destpulse.txz

mkdir -p $dest/usr/src/$soft-$softversion
( cd $buildir
cp -a build-$soft.sh $dest/usr/src/$soft-$softversion/
)

cd $dest
makepkg -l y -c n $dest.txz

# cleanup

rm -rf $dest
rm -rf $destpulse
rm -rf $src
